<?php

namespace Drupal\aggrid\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class aggridForm.
 */
class aggridForm extends EntityForm {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    $aggrid_entity = $this->entity;
    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#maxlength' => 255,
      '#default_value' => $aggrid_entity->label(),
      '#description' => $this->t("Label for the ag-Grid Entity."),
      '#required' => TRUE,
    ];

    $form['columnDefs'] = [
      '#type' => 'textarea',
      '#title' => t('ag-Grid JSON Columns'),
      '#default_value' => $aggrid_entity->get('columnDefs'),
      '#description' => t('Headers that will be used on the ag-Grid Entity'),
      '#required' => TRUE,
    ];

    $form['rowData'] = [
      '#type' => 'textarea',
      '#title' => t('ag-grid Default JSON Rows'),
      '#default_value' => $aggrid_entity->get('rowData'),
      '#description' => t('Default row data that will be used for the ag-Grid Entity'),
      '#required' => TRUE,
    ];

    $form['addOptions'] = [
      '#type' => 'textarea',
      '#title' => t('ag-Grid additional options'),
      '#default_value' => $aggrid_entity->get('addOptions'),
      '#description' => t('Additional Options that might be needed for the ag-Grid Entity'),
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $aggrid_entity->id(),
      '#machine_name' => [
        'exists' => '\Drupal\aggrid\Entity\aggridEntity::load',
      ],
      '#disabled' => !$aggrid_entity->isNew(),
    ];

    /* You will need additional form elements for your custom properties. */

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $aggrid = $this->entity;
    $status = $aggrid->save();

    switch ($status) {
      case SAVED_NEW:
        drupal_set_message($this->t('Created the %label ag-Grid Entity.', [
          '%label' => $aggrid->label(),
        ]));
        break;

      default:
        drupal_set_message($this->t('Saved the %label ag-Grid Entity.', [
          '%label' => $aggrid->label(),
        ]));
    }
    $form_state->setRedirectUrl($aggrid->toUrl('collection'));
  }

}
