<?php

namespace Drupal\aggrid\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Html;
use Drupal\Core\Field\FieldItemInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\aggrid\Entity;

/**
 * Plugin implementation of the 'aggrid_formatter_type' formatter.
 *
 * @FieldFormatter(
 *   id = "aggrid_formatter_type",
 *   label = @Translation("Aggrid formatter type"),
 *   field_types = {
 *     "aggrid"
 *   }
 * )
 */
class aggridFormatterType extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      // Implement default settings.
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    return [
      // Implement settings form.
    ] + parent::settingsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    // Implement settings summary.

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
/*
    foreach ($items as $delta => $item) {
      $elements[$delta] = ['#markup' => $this->viewValue($item)];
    }
*/

    foreach ($items as $delta => $item) {
      $this->setSetting(aggrid, 1);
      $field_settings = $this->getFieldSettings();

      $field_name = $this->fieldDefinition->getName();

      $item_id = Html::getUniqueId("ht-$field_name-$delta");

      $elements[$delta]['container'] = [
        '#suffix' => '<div class="aggrid-widget ag-theme-balham" id="' . $item_id . '_aggrid" data-edit="false" data-target="' . $item_id . '"></div>',
        '#attributes' => ['class' => ['aggrid-widget']],
        '#attached' => [
          'library' => [
            'aggrid/widget',
          ],
        ],
      ];

      if (isset($items[$delta]->aggrid_id)) {
        $aggridEntity = Entity\aggrid::load($items[$delta]->aggrid_id);

        if ($items[$delta]->value != '') {
          $aggridValue = substr($items[$delta]->value, 0, strlen($items[$delta]->value) - 1);
        } else {
          $aggridValue = '{"columnDefs": ' . $aggridEntity->get('columnDefs') . ', "rowData": ' . $aggridEntity->get('rowData');
        }
        if ($aggridEntity->get('addOptions') != '') {
          $aggridValue .= ', ' . $aggridEntity->get('addOptions');
        }
        $aggridValue .= '}';
      } else {
        $aggridValue = $items[$delta]->value;
      }

      $elements[$delta]['value'] = [
        '#type' => 'hidden',
        '#attributes' => ['id' => [$item_id]],
        '#value' => $aggridValue,
      ];

    }

    return $elements;
  }

  /**
   * Generate the output appropriate for one field item.
   *
   * @param \Drupal\Core\Field\FieldItemInterface $item
   *   One field item.
   *
   * @return string
   *   The textual output generated.
   */
  protected function viewValue(FieldItemInterface $item) {
    // The text value has no text format assigned to it, so the user input
    // should equal the output, including newlines.
    return nl2br(Html::escape($item->value));
  }

}
